@@ -34,8 +34,8 @@ class WebAuth:
             "",
             "Password to protect the mitmweb user interface. "
             "Values starting with `$` are interpreted as an argon2 hash, "
-            "everything else is considered a plaintext password."
-            "If not password is provided, a random token is generated on startup.",
+            "everything else is considered a plaintext password. "
+            "If no password is provided, a random token is generated on startup.",
         )
 
     def configure(self, updated) -> None:
@@ -94,9 +94,14 @@ class WebAddon:
             master: WebMaster = ctx.master  # type: ignore
             success = open_browser(master.web_url)
             if not success:
-                logging.info(
+                logger.info(
                     f"No web browser found. Please open a browser and point it to {master.web_url}",
                 )
+            if not success and not ctx.options.web_password:
+                logger.info(
+                    f"You can configure a fixed authentication token by setting the `web_password` option "
+                    f"(https://docs.mitmproxy.org/stable/concepts-options/#web_password).",
+                )
 
 
 def open_browser(url: str) -> bool:
